<?php

/**
 * 5pm api v2 example: create/read/update/remove projects
 */

define('API_HOST', 'demo.5pmweb.com');
define('API_USERNAME', 'blumbergh@initechweb.com');
define('API_PASSWORD', '1111');

require('lib/FivePm/Api.php');

try {
    $api = new FivePm\Api(API_HOST);

    // try to sign in
    if (!$api->signIn(API_USERNAME, API_PASSWORD)) {
        throw new Exception("Authorization failed");
    }

    // create a new project
    $project = $api->projects->add(
        array(
            'name' => "New Api project"
        )
    );

    // update the project
    $project->name       = $project->name . " (upd)";
    $projectUpdateResult = $api->projects->update($project);

    // create another project
    $anotherProject = $api->projects->add(
        array(
            'name' => "Another Api project",
        )
    );

    // add a task to the project
    $task = $api->tasks->add(
        array(
            'name'      => 'New api task',
            'projectId' => $project->id,
        )
    );

                  // update the task
    $task->name       = $task->name . ' (upd)';
    $taskUpdateResult = $api->tasks->update($task);

    // add another task
    $anotherTask = $api->tasks->add(
        array(
            'name'      => 'Another api task',
            'projectId' => $project->id,
        )
    );

    // add a sub-task to previously created task
    $subTask = $api->tasks->add(
        array(
            'name'     => 'New api sub-task',
            'parentId' => $task->id,
        )
    );

    // move the task to another project
    $task->projectId = $anotherProject->id;
    $api->tasks->update($task);

    // move another task to another project
    $anotherTask->projectId = $anotherProject->id;
    $api->tasks->update($anotherTask);

    // move $task as a sub-task of "$anotherTask"
    $task->parentId = $anotherTask->id;
    $api->tasks->update($task);

    // get 10 tasks from project
    $tasksList = $api->tasks->getList(
        array('projectId' => $project->id), // - filter
        0,      // - offset (by default '0')
        10,     // - count  (by default '20')
        true    // - load task team true/false (by default 'false')
    );

    // add a new message to the created project
    $msg = $api->activity->add(
        array(
            'type'      => 'msg',
            'projectId' => $project->id,
            'text'      => 'A message on api project',
        )
    );

    // add a new message to the created task
    $msgOnTask = $api->activity->add(
        array(
            'type'   => 'msg',
            'taskId' => $task->id,
            'text'   => 'A message on api task',
        )
    );

    // add a new progress to the created task
    $progressOnTask = $api->activity->add(
        array(
            'type'     => 'progress',
            'taskId'   => $task->id,
            'progress' => 34,
            'text'     => 'A progress note on api task',
        )
    );

    // add a new progress to the sub-task
    $progressOnSubTask = $api->activity->add(
        array(
            'type'     => 'progress',
            'taskId'   => $subTask->id,
            'progress' => 77,
            'text'     => 'A progress note on api task',
        )
    );

    // get 10 messages from task
    $msgList = $api->activity->getList(
       array('taskId' => $task->id), // - filter
       0,    // - offset (by default '0')
       10,   // - count  (by default '20')
       true, // - load files (by default 'false')
       true  // - load project/task name (by default 'false')
    );

    // remove the progress from the sub-task
    $api->activity->remove($progressOnSubTask->id);

    // remove the task
    $api->tasks->remove($task->id);

    // remove the project
    $api->projects->remove($project->id);

    // remove another project
    $api->projects->remove($anotherProject->id);

    // sign out
    $api->signOut();

    echo "The planet is safe now!\n";
} catch (Exception $exc) {
    echo "Something went wrong: " . $exc->getMessage() . "\n";
}
